[farsight2/master] Rename native codecs/candidates to local codecs/candidates to match ICE 19

Olivier Crête olivier.crete at collabora.co.uk
Tue Dec 23 15:19:19 PST 2008


---
 gst-libs/gst/farsight/fs-session.c            |   30 ++++++++++++------------
 gst-libs/gst/farsight/fs-stream-transmitter.c |   24 ++++++++++----------
 gst-libs/gst/farsight/fs-stream.c             |   28 +++++++++++-----------
 gst/fsrtpconference/fs-rtp-session.c          |    8 +++---
 gst/fsrtpconference/fs-rtp-stream.c           |   24 ++++++++++----------
 5 files changed, 57 insertions(+), 57 deletions(-)

diff --git a/gst/fsrtpconference/fs-rtp-session.c b/gst/fsrtpconference/fs-rtp-session.c
index 011a608..da34a68 100644
--- a/gst/fsrtpconference/fs-rtp-session.c
+++ b/gst/fsrtpconference/fs-rtp-session.c
@@ -52,8 +52,8 @@ enum
   PROP_MEDIA_TYPE,
   PROP_ID,
   PROP_SINK_PAD,
-  PROP_NATIVE_CODECS,
-  PROP_NATIVE_CODECS_CONFIG,
+  PROP_LOCAL_CODECS,
+  PROP_LOCAL_CODECS_CONFIG,
   PROP_NEGOTIATED_CODECS,
   PROP_CURRENT_SEND_CODEC,
   PROP_CONFERENCE
@@ -186,9 +186,9 @@ fs_rtp_session_class_init (FsRtpSessionClass *klass)
   g_object_class_override_property (gobject_class,
     PROP_SINK_PAD, "sink-pad");
   g_object_class_override_property (gobject_class,
-    PROP_NATIVE_CODECS, "native-codecs");
+    PROP_LOCAL_CODECS, "local-codecs");
   g_object_class_override_property (gobject_class,
-    PROP_NATIVE_CODECS_CONFIG, "native-codecs-config");
+    PROP_LOCAL_CODECS_CONFIG, "local-codecs-config");
   g_object_class_override_property (gobject_class,
     PROP_NEGOTIATED_CODECS, "negotiated-codecs");
   g_object_class_override_property (gobject_class,
diff --git a/gst-libs/gst/farsight/fs-session.c b/gst-libs/gst/farsight/fs-session.c
index ebb4da1..655a8b8 100644
--- a/gst-libs/gst/farsight/fs-session.c
+++ b/gst-libs/gst/farsight/fs-session.c
@@ -61,8 +61,8 @@ enum
   PROP_MEDIA_TYPE,
   PROP_ID,
   PROP_SINK_PAD,
-  PROP_NATIVE_CODECS,
-  PROP_NATIVE_CODECS_CONFIG,
+  PROP_LOCAL_CODECS,
+  PROP_LOCAL_CODECS_CONFIG,
   PROP_NEGOTIATED_CODECS,
   PROP_CURRENT_SEND_CODEC
 };
@@ -185,39 +185,39 @@ fs_session_class_init (FsSessionClass *klass)
         G_PARAM_READABLE));
 
   /**
-   * FsSession:native-codecs:
+   * FsSession:local-codecs:
    *
    * This is the list of native codecs that have been auto-detected based on
    * installed GStreamer plugins. This list is unchanged during the lifecycle of
    * the session unless native-codecs-config is changed by the user. It is a
    * #GList of #FsCodec. User must free this codec list using
    * #fs_codec_list_destroy() when done.
    *
    */
   g_object_class_install_property (gobject_class,
-      PROP_NATIVE_CODECS,
-      g_param_spec_boxed ("native-codecs",
-        "List of native codecs",
+      PROP_LOCAL_CODECS,
+      g_param_spec_boxed ("local-codecs",
+        "List of local codecs",
         "A GList of FsCodecs that can be used for sending",
         FS_TYPE_CODEC_LIST,
         G_PARAM_READABLE));
 
   /**
-   * FsSession:native-codecs-config:
+   * FsSession:local-codecs-config:
    *
    * This is the current configuration list for the native codecs. It is usually
    * set by the user to specify the codec options and priorities. The user may
    * change this value during an ongoing session. Note that doing this can cause
    * the native-codecs to be changed. Therefore this requires the user to fetch
    * the new native-codecs and renegotiate them with the peers. It is a #GList
    * of #FsCodec. User must free this codec list using #fs_codec_list_destroy()
    * when done.
    *
    */
   g_object_class_install_property (gobject_class,
-      PROP_NATIVE_CODECS_CONFIG,
-      g_param_spec_boxed ("native-codecs-config",
-        "List of user configuration for native codecs",
+      PROP_LOCAL_CODECS_CONFIG,
+      g_param_spec_boxed ("local-codecs-config",
+        "List of user configuration for local codecs",
         "A GList of FsCodecs that allows user to set his codec options and"
         " priorities",
         FS_TYPE_CODEC_LIST,
@@ -185,39 +185,39 @@ fs_session_class_init (FsSessionClass *klass)
    *
-   * This is the list of native codecs that have been auto-detected based on
+   * This is the list of local codecs that have been auto-detected based on
    * installed GStreamer plugins. This list is unchanged during the lifecycle of
@@ -185,39 +185,39 @@ fs_session_class_init (FsSessionClass *klass)
    * installed GStreamer plugins. This list is unchanged during the lifecycle of
-   * the session unless native-codecs-config is changed by the user. It is a
+   * the session unless local-codecs-config is changed by the user. It is a
    * #GList of #FsCodec. User must free this codec list using
    * #fs_codec_list_destroy() when done.
@@ -185,39 +185,39 @@ fs_session_class_init (FsSessionClass *klass)
    *
-   * This is the current configuration list for the native codecs. It is usually
+   * This is the current configuration list for the local codecs. It is usually
    * set by the user to specify the codec options and priorities. The user may
    * change this value during an ongoing session. Note that doing this can cause
@@ -185,39 +185,39 @@ fs_session_class_init (FsSessionClass *klass)
    * set by the user to specify the codec options and priorities. The user may
    * change this value during an ongoing session. Note that doing this can cause
-   * the native-codecs to be changed. Therefore this requires the user to fetch
-   * the new native-codecs and renegotiate them with the peers. It is a #GList
+   * the local-codecs to be changed. Therefore this requires the user to fetch
+   * the new local-codecs and renegotiate them with the peers. It is a #GList
    * of #FsCodec. User must free this codec list using #fs_codec_list_destroy()
    * when done.
diff --git a/gst-libs/gst/farsight/fs-stream-transmitter.c b/gst-libs/gst/farsight/fs-stream-transmitter.c
index 1a9e062..e71899f 100644
--- a/gst-libs/gst/farsight/fs-stream-transmitter.c
+++ b/gst-libs/gst/farsight/fs-stream-transmitter.c
@@ -47,9 +47,9 @@
 enum
 {
   ERROR,
-  NEW_NATIVE_CANDIDATE,
+  NEW_LOCAL_CANDIDATE,
   NEW_ACTIVE_CANDIDATE_PAIR,
-  NATIVE_CANDIDATES_PREPARED,
+  LOCAL_CANDIDATES_PREPARED,
   LAST_SIGNAL
 };
 
@@ -160,7 +160,7 @@ fs_stream_transmitter_class_init (FsStreamTransmitterClass *klass)
     /**
    * FsStreamTransmitter::new-active-candidate-pair:
    * @self: #FsStream that emitted the signal
    * @native_candidate: #FsCandidate of the native candidate being used
    * @remote_candidate: #FsCandidate of the remote candidate being used
    *
    * This signal is emitted when there is a new active chandidate pair that has
@@ -181,15 +181,15 @@ fs_stream_transmitter_class_init (FsStreamTransmitterClass *klass)
       G_TYPE_NONE, 2, FS_TYPE_CANDIDATE, FS_TYPE_CANDIDATE);
 
  /**
-   * FsStreamTransmitter::new-native-candidate:
+   * FsStreamTransmitter::new-local-candidate:
    * @self: #FsStream that emitted the signal
    * @native_candidate: #FsCandidate of the native candidate
    *
    * This signal is emitted when a new native candidate is discovered.
    *
    */
-  signals[NEW_NATIVE_CANDIDATE] = g_signal_new
-    ("new-native-candidate",
+  signals[NEW_LOCAL_CANDIDATE] = g_signal_new
+    ("new-local-candidate",
       G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
       0,
@@ -199,15 +199,15 @@ fs_stream_transmitter_class_init (FsStreamTransmitterClass *klass)
       G_TYPE_NONE, 1, FS_TYPE_CANDIDATE);
 
  /**
-   * FsStreamTransmitter::native-candidates-prepared:
+   * FsStreamTransmitter::local-candidates-prepared:
    * @self: #FsStream that emitted the signal
    *
    * This signal is emitted when all native candidates have been
    * prepared, an ICE implementation would send its SDP offer or answer.
    *
    */
-  signals[NATIVE_CANDIDATES_PREPARED] = g_signal_new
-    ("native-candidates-prepared",
+  signals[LOCAL_CANDIDATES_PREPARED] = g_signal_new
+    ("local-candidates-prepared",
       G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
       0,
@@ -160,7 +160,7 @@ fs_stream_transmitter_class_init (FsStreamTransmitterClass *klass)
    * FsStreamTransmitter::new-active-candidate-pair:
    * @self: #FsStream that emitted the signal
-   * @native_candidate: #FsCandidate of the native candidate being used
+   * @local_candidate: #FsCandidate of the local candidate being used
    * @remote_candidate: #FsCandidate of the remote candidate being used
    *
@@ -181,15 +181,15 @@ fs_stream_transmitter_class_init (FsStreamTransmitterClass *klass)
    * @self: #FsStream that emitted the signal
-   * @native_candidate: #FsCandidate of the native candidate
+   * @local_candidate: #FsCandidate of the local candidate
    *
@@ -181,15 +181,15 @@ fs_stream_transmitter_class_init (FsStreamTransmitterClass *klass)
    *
-   * This signal is emitted when a new native candidate is discovered.
+   * This signal is emitted when a new local candidate is discovered.
    *
    */
@@ -199,15 +199,15 @@ fs_stream_transmitter_class_init (FsStreamTransmitterClass *klass)
    * @self: #FsStream that emitted the signal
    *
-   * This signal is emitted when all native candidates have been
+   * This signal is emitted when all local candidates have been
    * prepared, an ICE implementation would send its SDP offer or answer.
    *
diff --git a/gst-libs/gst/farsight/fs-stream.c b/gst-libs/gst/farsight/fs-stream.c
index 306af24..85fcbbe 100644
--- a/gst-libs/gst/farsight/fs-stream.c
+++ b/gst-libs/gst/farsight/fs-stream.c
@@ -54,8 +54,8 @@ enum
   SRC_PAD_ADDED,
   RECV_CODEC_CHANGED,
   NEW_ACTIVE_CANDIDATE_PAIR,
-  NEW_NATIVE_CANDIDATE,
-  NATIVE_CANDIDATES_PREPARED,
+  NEW_LOCAL_CANDIDATE,
+  LOCAL_CANDIDATES_PREPARED,
   LAST_SIGNAL
 };
 
@@ -355,7 +355,7 @@ fs_stream_class_init (FsStreamClass *klass)
   /**
    * FsStream::new-active-candidate-pair:
    * @self: #FsStream that emitted the signal
    * @native_candidate: #FsCandidate of the native candidate being used
    * @remote_candidate: #FsCandidate of the remote candidate being used
    *
    * This signal is emitted when there is a new active chandidate pair that has
@@ -376,15 +376,15 @@ fs_stream_class_init (FsStreamClass *klass)
       G_TYPE_NONE, 2, FS_TYPE_CANDIDATE, FS_TYPE_CANDIDATE);
 
  /**
-   * FsStream::new-native-candidate:
+   * FsStream::new-local-candidate:
    * @self: #FsStream that emitted the signal
    * @native_candidate: #FsCandidate of the native candidate
    *
    * This signal is emitted when a new native candidate is discovered.
    *
    */
-  signals[NEW_NATIVE_CANDIDATE] = g_signal_new
-    ("new-native-candidate",
+  signals[NEW_LOCAL_CANDIDATE] = g_signal_new
+    ("new-local-candidate",
       G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
       0,
@@ -394,15 +394,15 @@ fs_stream_class_init (FsStreamClass *klass)
       G_TYPE_NONE, 1, FS_TYPE_CANDIDATE);
 
  /**
-   * FsStream::native-candidates-prepared:
+   * FsStream::local-candidates-prepared:
    * @self: #FsStream that emitted the signal
    *
    * This signal is emitted when all native candidates have been
    * prepared, an ICE implementation would send its SDP offer or answer.
    *
    */
-  signals[NATIVE_CANDIDATES_PREPARED] = g_signal_new
-    ("native-candidates-prepared",
+  signals[LOCAL_CANDIDATES_PREPARED] = g_signal_new
+    ("local-candidates-prepared",
       G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
       0,
@@ -498,7 +498,7 @@ fs_stream_add_remote_candidate (FsStream *stream, FsCandidate *candidate,
  * @error: location of a #GError, or NULL if no error occured
  *
  * This function will preload the codec corresponding to the given codec.
  * This codec must correspond exactly to one of the native-codecs returned by
  * the #FsSession that spawned this #FsStream. Preloading a codec is useful for
  * machines where loading the codec is slow. When preloading, decoding can start
  * as soon as a stream is received.
@@ -528,7 +528,7 @@ fs_stream_preload_recv_codec (FsStream *stream, FsCodec *codec, GError **error)
  * @error: location of a #GError, or NULL if no error occured
  *
  * This function will set the list of remote codecs for this stream. If
  * the given remote codecs couldn't be negotiated with the list of native
  * codecs or already negotiated codecs for the corresponding #FsSession, @error
  * will be set and %FALSE will be returned. The @remote_codecs list will be
  * copied so it must be free'd using fs_codec_list_destroy() when done.
@@ -355,7 +355,7 @@ fs_stream_class_init (FsStreamClass *klass)
    * FsStream::new-active-candidate-pair:
    * @self: #FsStream that emitted the signal
-   * @native_candidate: #FsCandidate of the native candidate being used
+   * @local_candidate: #FsCandidate of the local candidate being used
    * @remote_candidate: #FsCandidate of the remote candidate being used
    *
@@ -376,15 +376,15 @@ fs_stream_class_init (FsStreamClass *klass)
    * @self: #FsStream that emitted the signal
-   * @native_candidate: #FsCandidate of the native candidate
+   * @local_candidate: #FsCandidate of the local candidate
    *
@@ -376,15 +376,15 @@ fs_stream_class_init (FsStreamClass *klass)
    *
-   * This signal is emitted when a new native candidate is discovered.
+   * This signal is emitted when a new local candidate is discovered.
    *
    */
@@ -394,15 +394,15 @@ fs_stream_class_init (FsStreamClass *klass)
    * @self: #FsStream that emitted the signal
    *
-   * This signal is emitted when all native candidates have been
+   * This signal is emitted when all local candidates have been
    * prepared, an ICE implementation would send its SDP offer or answer.
    *
@@ -498,7 +498,7 @@ fs_stream_add_remote_candidate (FsStream *stream, FsCandidate *candidate,
  *
  * This function will preload the codec corresponding to the given codec.
- * This codec must correspond exactly to one of the native-codecs returned by
+ * This codec must correspond exactly to one of the local-codecs returned by
  * the #FsSession that spawned this #FsStream. Preloading a codec is useful for
  * machines where loading the codec is slow. When preloading, decoding can start
@@ -528,7 +528,7 @@ fs_stream_preload_recv_codec (FsStream *stream, FsCodec *codec, GError **error)
  *
  * This function will set the list of remote codecs for this stream. If
- * the given remote codecs couldn't be negotiated with the list of native
+ * the given remote codecs couldn't be negotiated with the list of local
  * codecs or already negotiated codecs for the corresponding #FsSession, @error
  * will be set and %FALSE will be returned. The @remote_codecs list will be
diff --git a/gst/fsrtpconference/fs-rtp-stream.c b/gst/fsrtpconference/fs-rtp-stream.c
index aece829..5df0f8a 100644
--- a/gst/fsrtpconference/fs-rtp-stream.c
+++ b/gst/fsrtpconference/fs-rtp-stream.c
@@ -100,7 +100,7 @@ static gboolean fs_rtp_stream_set_remote_codecs (FsStream *stream,
                                                  GList *remote_codecs,
                                                  GError **error);
 
-static void fs_rtp_stream_native_candidates_prepared (
+static void fs_rtp_stream_local_candidates_prepared (
     FsStreamTransmitter *stream_transmitter,
     gpointer user_data);
 static void fs_rtp_stream_new_active_candidate_pair (
@@ -108,7 +108,7 @@ static void fs_rtp_stream_new_active_candidate_pair (
     FsCandidate *candidate1,
     FsCandidate *candidate2,
     gpointer user_data);
-static void fs_rtp_stream_new_native_candidate (
+static void fs_rtp_stream_new_local_candidate (
     FsStreamTransmitter *stream_transmitter,
     FsCandidate *candidate,
     gpointer user_data);
@@ -322,16 +322,16 @@ fs_rtp_stream_constructed (GObject *object)
     self->priv->direction & FS_DIRECTION_SEND, NULL);
 
   g_signal_connect (self->priv->stream_transmitter,
-    "native-candidates-prepared",
-    G_CALLBACK (fs_rtp_stream_native_candidates_prepared),
+    "local-candidates-prepared",
+    G_CALLBACK (fs_rtp_stream_local_candidates_prepared),
     self);
   g_signal_connect (self->priv->stream_transmitter,
     "new-active-candidate-pair",
     G_CALLBACK (fs_rtp_stream_new_active_candidate_pair),
     self);
   g_signal_connect (self->priv->stream_transmitter,
-    "new-native-candidate",
-    G_CALLBACK (fs_rtp_stream_new_native_candidate),
+    "new-local-candidate",
+    G_CALLBACK (fs_rtp_stream_new_local_candidate),
     self);
   g_signal_connect (self->priv->stream_transmitter,
     "error",
@@ -369,7 +369,7 @@ fs_rtp_stream_add_remote_candidate (FsStream *stream, FsCandidate *candidate,
  * @error: location of a #GError, or NULL if no error occured
  *
  * This function will preload the codec corresponding to the given codec.
  * This codec must correspond exactly to one of the native-codecs returned by
  * the #FsSession that spawned this #FsStream. Preloading a codec is useful for
  * machines where loading the codec is slow. When preloading, decoding can start
  * as soon as a stream is received.
@@ -390,7 +390,7 @@ fs_rtp_stream_preload_recv_codec (FsStream *stream, FsCodec *codec,
  * @error: location of a #GError, or NULL if no error occured
  *
  * This function will set the list of remote codecs for this stream. If
  * the given remote codecs couldn't be negotiated with the list of native
  * codecs or already negotiated codecs for the corresponding #FsSession, @error
  * will be set and %FALSE will be returned. The @remote_codecs list will be
  * copied so it must be free'd using fs_codec_list_destroy() when done.
@@ -426,12 +426,12 @@ fs_rtp_stream_new_recv_pad (FsRtpStream *stream, GstPad *pad, guint pt)
 }
 
 static void
-fs_rtp_stream_native_candidates_prepared (
+fs_rtp_stream_local_candidates_prepared (
     FsStreamTransmitter *stream_transmitter, gpointer user_data)
 {
   FsRtpStream *self = FS_RTP_STREAM (user_data);
 
-  g_signal_emit_by_name (self, "native-candidates-prepared", 0);
+  g_signal_emit_by_name (self, "local-candidates-prepared", 0);
 }
 
 
@@ -450,14 +450,14 @@ fs_rtp_stream_new_active_candidate_pair (
 
 
 static void
-fs_rtp_stream_new_native_candidate (
+fs_rtp_stream_new_local_candidate (
     FsStreamTransmitter *stream_transmitter,
     FsCandidate *candidate,
     gpointer user_data)
 {
   FsRtpStream *self = FS_RTP_STREAM (user_data);
 
-  g_signal_emit_by_name (self, "new-native-candidate", 0, candidate);
+  g_signal_emit_by_name (self, "new-local-candidate", 0, candidate);
 }
 
 static void
@@ -369,7 +369,7 @@ fs_rtp_stream_add_remote_candidate (FsStream *stream, FsCandidate *candidate,
  *
  * This function will preload the codec corresponding to the given codec.
- * This codec must correspond exactly to one of the native-codecs returned by
+ * This codec must correspond exactly to one of the local-codecs returned by
  * the #FsSession that spawned this #FsStream. Preloading a codec is useful for
  * machines where loading the codec is slow. When preloading, decoding can start
@@ -390,7 +390,7 @@ fs_rtp_stream_preload_recv_codec (FsStream *stream, FsCodec *codec,
  *
  * This function will set the list of remote codecs for this stream. If
- * the given remote codecs couldn't be negotiated with the list of native
+ * the given remote codecs couldn't be negotiated with the list of local
  * codecs or already negotiated codecs for the corresponding #FsSession, @error
  * will be set and %FALSE will be returned. The @remote_codecs list will be
-- 
1.5.6.5




More information about the farsight-commits mailing list